compute_rebuild_path_flags

Function compute_rebuild_path_flags 

pub fn compute_rebuild_path_flags<I, L>(
    bvh: &Bvh2,
    leaves: I,
    flags: &mut Vec<bool>,
)
where I: IntoIterator<Item = L>, L: Borrow<u32>,
Provide a set of leaves that need to be rebuilt. After calling, flags will be true for any node index up the tree that needs to be included in the partial rebuild.