pub fn compute_rebuild_path_flags<I, L>(
bvh: &Bvh2,
leaves: I,
flags: &mut Vec<bool>,
)Expand description
Provide a set of leaves that need to be rebuilt. After calling, flags will be true for any node index up the tree that needs to be included in the partial rebuild.